@@ -72,50 +72,33 @@ def opensource(module='pyextension'):
         raise AttributeError('\'opensource\' object has no attribute \'%s\'' % module)
 
 def license():
-    file = open('LICENSE')
+    file = open('LICENSE.py')
     get = file.read()
     file.close()
     return get
 
-from lxml import etree
-
 def description():
-    html = '''
-<!DOCTYPE html>
-<html>
-  <head>
-    Brief Introduction
-  </head>
-  <p></p>
-  <font size='2'>
-    Python-Extension is an extension of Python,
+    return '''
+Brief Introduction
+
+Python-Extension is an extension of Python,
 It is divided into pyextension and tkextension,
 tkextension is particularly powerful. 
-  </font>
-  <p></p>
-  <head>
-    Pyextension
-  </head>
-  <p></p>
-  <font size='2'>
-    Pyextension includes main modules
+
+
+Pyextension
+
+Pyextension includes main modules
 (open source function, computer information function and digital conversion function),
 mathematical function processing module, password encryption module,
 English Thesaurus module and Microsoft Word document processing module.
-  </font>
-  <p></p>
-  <head>
-    Tkextension
-  </head>
-  <p></p>
-  <font size='2'>
-    Tkextense includes dialog window,tix widget,
+
+
+Tkextension
+
+Tkextense includes dialog window,tix widget,
 quick generation of Tkinter object,
 quick document processing (open and save as),
 open source module, about module,
 small blackboard module, turtle graphics drawing module and timer module
-  </font>
-</html>
 '''
-    html = etree.HTML(html)
-    return html
