@@ -1,6 +1,6 @@
 import sys
 if sys.version_info[0] != 3 or sys.version_info[1] < 10:
-    raise SystemExit('Python version too low, at least Python 3.10 can use this module')
+    raise SystemExit('This module needs Python 3.10 or more later')
 
 from tkinter import *
 from docx import *
@@ -103,3 +103,4 @@ def add_heading(text, attribute=Document(), mode=(None), heading=(True, 'normal'
             case _:
                 raise AttributeError('\'add_heading - heading - mode\' object has no attribute \'%s\'' % heading[1])
     return attribute
+
